pub trait FixedBitsOptionalArbitrary: Sealedwhere
Self: for<'a> Arbitrary<'a>,{ }Expand description
This trait is used to provide supertrait to the FixedBits trait
depending on the crates’s optional features, and should not be used
directly.
If the arbitrary feature is enabled, Arbitrary is a supertrait of
FixedBits.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.