Module prelude

Module prelude 

A prelude to import useful traits.

This prelude is similar to the standard library’s prelude in that you’ll almost always want to import its entire contents, but unlike the standard library’s prelude you’ll have to do so manually:

use fixed::prelude::*;

The prelude may grow over time as additional items see ubiquitous use.

Contents

The prelude re-exports the following:

Re-exports

pub use crate::traits::FromFixed;
pub use crate::traits::LosslessTryFrom;
pub use crate::traits::LosslessTryInto;
pub use crate::traits::LossyFrom;
pub use crate::traits::LossyInto;
pub use crate::traits::ToFixed;